<?php

declare(strict_types=1);

namespace mirzaev\parser_from_rossko;

use avadim\FastExcelWriter\Excel as excel;

use ZipArchive as zip,
	DirectoryIterator as directory;

use SQLite3 as db;

use GuzzleHttp\Client as client,
	GuzzleHttp\Psr7\Request as request,
	GuzzleHttp\Psr7\Utils as utils;

ini_set('error_reporting', E_ALL);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

define('VIEWS', realpath(__DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'views'));
define('STORAGE', realpath(__DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'storage'));
define('INDEX', __DIR__);

// Автозагрузка
require INDEX . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'vendor' . DIRECTORY_SEPARATOR . 'autoload.php';

// Инициализация инстанции абстрактной базы данных
$db = new db(STORAGE . DIRECTORY_SEPARATOR . 'products.db');

// Инициализация товаров
$products = $db->query('SELECT * FROM product;');

// Инициализация директории с документом Drom
define('DROM', STORAGE . DIRECTORY_SEPARATOR . 'drom');

// Инициализация хранилища фотографий товаров
define('IMAGES', STORAGE . DIRECTORY_SEPARATOR . 'images');

// Инициализация таблицы
$spreadsheet = excel::create(['export']);

// Инициализация рабочего листа
$worksheet = $spreadsheet->sheet();

// Инициализация заголовков
$worksheet->writeHeader([
	'Артикул',
	'Наименование товара',
	'Новый или б/у',
	'Марка',
	'Модель',
	'Кузов',
	'Номер',
	'Производитель',
	'Двигатель',
	'Год',
	'L-R',
	'F-R',
	'U-D',
	'Цвет',
	'Номера замен',
	'Применимость',
	'Примечание',
	'Количество',
	'Цена',
	'Наличие',
	'Сроки доставки',
	'Фотография'
]);

while ($product = $products->fetchArray()) {
	// Перебор товаров

	// Пропустить товары с отсутствием названия
	if (empty($product['description'])) continue;

	// Инициализация списка изображений товара
	$images = [];

	// Поиск изображений
	if (file_exists($file = IMAGES . DIRECTORY_SEPARATOR . $product['nomenclature']))
		foreach (new directory($file) as $file)
			if (strtolower($file->getExtension()) === 'jpg')
				$images[] = "https://vinauto.store/{$product['nomenclature']}/{$file->getFilename()}";

	// Около 40% товаров из Rossko без изображений и drom их не принимает! Временное решение
	if (empty($images)) continue;

	// Преобразование типов
	$product['cost'] = (float) $product['cost'];

	// Инициализация списков
	$brands = $models = $engines = [];

	foreach (json_decode((string) $product['applicability'], true) ?? [] as $brand) {
		// Перебор марок автомобилей

		// Запись в список марок
		$brands[] = $brand['name'];

		foreach ($brand['carModels'] as $model) {
			// Перебор моделей автомобилей

			// Запись в список моделей
			$models[] = $model['name'];

			foreach ($model['engines'] as $engine) {
				// Перебор двигателей автомобилей

				// Запись в список двигателей
				$engines[] = $engine;
			}
		}
	}

	// Ограничение по максимальному количеству
	$brands = array_slice($brands, 0, 5);
	$models = array_slice($models, 0, 10);
	$engines = array_slice($engines, 0, 30);

	// Форматирование названия
	$product['description'] = trim(preg_replace('/\|.*/', '', $product['description']), ' ');

	// Запись строки
	$worksheet->writeRow([
		$product['code'],
		$product['description'],
		'Новый',
		implode(', ', $brands),
		implode(', ', $models),
		'',
		'',
		$product['brand'],
		implode(', ', $engines),
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'По запчастям уточняйте наличие по телефону или через кнопку "спросить", ТАК КАК ОН МОЖЕТ БЫТЬ ПРОДАН В ТЕЧЕНИИ ДНЯ ИЛИ НАХОДИТЬСЯ В РЕЗЕРВЕ, часть запчастей находится на складе, на перемещение может потребоваться от 2 часов',
		rand(1, 6),
		(int) ($product['cost_rossko'] + ($product['cost_rossko'] * 0.23)),
		'В наличии',
		1,
		implode(' ', $images)
	]);
}

// Сохранение файла
$spreadsheet->save(DROM . DIRECTORY_SEPARATOR . 'export.xlsx');
